diff --git a/GMW/WebUserControls/mod_selLineaNtDt.ascx b/GMW/WebUserControls/mod_selLineaNtDt.ascx
index f75c8d5d..da3bd269 100644
--- a/GMW/WebUserControls/mod_selLineaNtDt.ascx
+++ b/GMW/WebUserControls/mod_selLineaNtDt.ascx
@@ -8,6 +8,7 @@
+
LINEA
diff --git a/GMW/WebUserControls/mod_selLineaNtDt.ascx.designer.cs b/GMW/WebUserControls/mod_selLineaNtDt.ascx.designer.cs
index f5eafed7..8ccb7cf2 100644
--- a/GMW/WebUserControls/mod_selLineaNtDt.ascx.designer.cs
+++ b/GMW/WebUserControls/mod_selLineaNtDt.ascx.designer.cs
@@ -39,6 +39,15 @@ namespace GMW.WebUserControls {
///
protected global::System.Web.UI.WebControls.Label lblShowHideStorico;
+ ///
+ /// lblPost control.
+ ///
+ ///
+ /// Auto-generated field.
+ /// To modify move field declaration from designer file to code-behind file.
+ ///
+ protected global::System.Web.UI.WebControls.Label lblPost;
+
///
/// ddlLinea control.
///
diff --git a/GMW/bin/GMW.dll b/GMW/bin/GMW.dll
index c98e3975..574a7026 100644
Binary files a/GMW/bin/GMW.dll and b/GMW/bin/GMW.dll differ
diff --git a/GMW/bin/GMW_data.dll b/GMW/bin/GMW_data.dll
index 19f437dd..fbe4097d 100644
Binary files a/GMW/bin/GMW_data.dll and b/GMW/bin/GMW_data.dll differ
diff --git a/GMW/bin/SteamWare.xml b/GMW/bin/SteamWare.xml
index 7d95ca7b..8fa8ef37 100644
--- a/GMW/bin/SteamWare.xml
+++ b/GMW/bin/SteamWare.xml
@@ -4560,7 +4560,7 @@
- è un boolean che indica se in session ci siano user/dominio e quindi utente autenticato in rpecedenza...
+ è un boolean che indica se in session ci siano user/dominio e quindi utente autenticato in precedenza...
diff --git a/GMW/bin/Web.config b/GMW/bin/Web.config
new file mode 100644
index 00000000..0dc44339
--- /dev/null
+++ b/GMW/bin/Web.config
@@ -0,0 +1,404 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
\ No newline at end of file
diff --git a/GMW_data/bin/IIS01_TK/GMW_data.dll.config b/GMW_data/bin/IIS01_TK/GMW_data.dll.config
new file mode 100644
index 00000000..1c108f05
--- /dev/null
+++ b/GMW_data/bin/IIS01_TK/GMW_data.dll.config
@@ -0,0 +1,17 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
\ No newline at end of file
diff --git a/GMW/WebUserControls/mod_selLineaNtDt.ascx.cs b/GMW/WebUserControls/mod_selLineaNtDt.ascx.cs
index 767a9b40..d8b236ed 100644
--- a/GMW/WebUserControls/mod_selLineaNtDt.ascx.cs
+++ b/GMW/WebUserControls/mod_selLineaNtDt.ascx.cs
@@ -499,8 +499,8 @@ namespace GMW.WebUserControls
resetPostazione();
if (codLinea != "")
{
- // se la linea non è "base" = "Sel linea", finisce x "0"
- if (codLinea.Substring(codLinea.Length - 1) != "0")
+ // se la linea non è "base" = "Sel linea", finisce x "00"
+ if (codLinea.Substring(codLinea.Length - 2) != "00")
{
// salvo su DB che sto occupando linea...
MagClass.magazzino.taAL.updatePost(codLinea, Postazione.name);